Index: src/wp-admin/credits.php
===================================================================
--- src/wp-admin/credits.php	(revision 32130)
+++ src/wp-admin/credits.php	(working copy)
@@ -82,7 +82,7 @@
 
 <h1><?php printf( __( 'Welcome to WordPress %s' ), $display_version ); ?></h1>
 
-<div class="about-text"><?php printf( __( 'Thank you for updating! WordPress %s helps you focus on your writing, and the new default theme lets you show it off in style.' ), $display_version ); ?></div>
+<div class="about-text"><?php printf( __( 'Thank you for updating! WordPress %s helps you communicate and share, globally.' ), $display_version ); ?></div>
 
 <div class="wp-badge"><?php printf( __( 'Version %s' ), $display_version ); ?></div>
 
Index: src/wp-admin/freedoms.php
===================================================================
--- src/wp-admin/freedoms.php	(revision 32130)
+++ src/wp-admin/freedoms.php	(working copy)
@@ -19,7 +19,7 @@
 
 <h1><?php printf( __( 'Welcome to WordPress %s' ), $display_version ); ?></h1>
 
-<div class="about-text"><?php printf( __( 'Thank you for updating! WordPress %s helps you focus on your writing, and the new default theme lets you show it off in style.' ), $display_version ); ?></div>
+<div class="about-text"><?php printf( __( 'Thank you for updating! WordPress %s helps you communicate and share, globally.' ), $display_version ); ?></div>
 
 <div class="wp-badge"><?php printf( __( 'Version %s' ), $display_version ); ?></div>
 

Index: src/wp-admin/about.php
===================================================================
--- src/wp-admin/about.php	(revision 32130)
+++ src/wp-admin/about.php	(working copy)
@@ -63,8 +63,8 @@
 			<h3><?php echo ( 'Extended Character Support' ); ?></h3>
 			<p><?php echo ( 'Writing in WordPress, whatever your language, just got better. WordPress 4.2 supports a host of new characters out-of-the-box, including native Chinese, Japanese, and Korean characters, musical and mathematical symbols, and hieroglyphs.' ); ?></p>
 			<p><?php
-				/* translators: 1: heart emoji, 2: kitten emoji, 3, monkey emoji, 4: ice-cream emoji */
-				printf( 'Don’t use special characters? You can still have fun &mdash; emoji are now available in WordPress! Get creative and decorate your content with %1$s, %2$s, %3$s, %4$s, and all the many other emojis.', '&#x1F499', '&#x1F408', '&#x1F412', '&#x1F366' );
+				/* translators: 1: heart emoji, 2: kitten emoji, 3, monkey emoji, 4: ice-cream emoji, 5: Emoji Codex link */
+				printf( 'Don’t use special characters? You can still have fun &mdash; emoji are now available in WordPress! Get creative and decorate your content with %1$s, %2$s, %3$s, %4$s, and all the many other <a href="%5$s">emojis</a>.', '&#x1F499', '&#x1F408', '&#x1F412', '&#x1F366', __( 'https://codex.wordpress.org/Emoji' ) );
 			?></p>
 		</div>
 		<div class="col">
@@ -134,15 +134,15 @@
 			<h4><?php echo ( 'utf8mb4 Support' ); ?></h4>
 			<p><?php echo ( 'Database character encoding has changed from utf8 to utf8mb4, which adds support for a whole range of new 4-byte characters.' ); ?></p>
 
-			<h4><?php echo ( 'Complex Query Ordering' ); ?></h4>
-			<p><?php echo ( '<code>WP_Query</code>, <code>WP_Comment_Query</code>, and <code>WP_User_Query</code> now support complex ordering with named meta query clauses.' ); ?></p>
+			<h4><?php echo ( 'JavaScript Accessibility' ); ?></h4>
+			<p><?php echo ( 'You can now send audible notifications to screen readers in JavaScript with <code>wp.a11y.speak()</code>. Pass it a string, and an update will be sent to the ARIA live notifications area.' ); ?></p>
 		</div>
 		<div class="last-feature">
 			<h4><?php echo ( 'Taxonomy Roadmap' ); ?></h4>
 			<p><?php echo ( 'Terms previously shared across multiple taxonomies will be split when one of them is updated. A new row is created in the database for each.' ); ?></p>
 
-			<h4><?php echo ( 'JavaScript Accessibility' ); ?></h4>
-			<p><?php echo ( 'Your JavaScript can now talk to screen readers with <code>wp.a11y.speak()</code>.' ); ?></p>
+			<h4><?php echo ( 'Complex Query Ordering' ); ?></h4>
+			<p><?php echo ( '<code>WP_Query</code>, <code>WP_Comment_Query</code>, and <code>WP_User_Query</code> now support complex ordering with named meta query clauses.' ); ?></p>
 		</div>
 
 	<hr />